"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

var _path = require("path");

var _yargs = _interopRequireDefault(require("yargs"));

var glob = _interopRequireWildcard(require("glob"));

var _chalk = _interopRequireDefault(require("chalk"));

var _index = require("./index.js");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/* eslint no-console: off */
var argv = _yargs["default"].usage('Usage: $0 <fixtures> [options]').option('cwd', {
  required: false,
  "default": process.cwd(),
  normalize: true,
  type: 'string',
  describe: 'Working directory where the .graphqlconfig is located'
}).option('show-passes', {
  type: 'boolean',
  "default": false,
  describe: 'Display passing fixtures along with failures in the console output'
}).help().argv;

(0, _index.evaluateFixtures)(glob.sync(argv._[0]), {
  cwd: argv.cwd
}).then(function (evaluations) {
  var passed = 0;
  var failed = 0;
  var lastFailed = false;
  console.log();
  evaluations.forEach(function (evaluation) {
    var relativePath = (0, _path.relative)(argv.cwd, evaluation.fixturePath);
    var formattedPath = "".concat(_chalk["default"].dim(relativePath.replace((0, _path.basename)(relativePath), ''))).concat(_chalk["default"].bold((0, _path.basename)(relativePath)));

    if (evaluation.scriptError) {
      failed += 1;
      lastFailed = true;
      console.log("".concat(_chalk["default"].inverse.bold.red(' FAIL '), " ").concat(formattedPath));
      console.log(evaluation.scriptError.message);

      if (evaluation.scriptError.stack) {
        console.log(_chalk["default"].dim(evaluation.scriptError.stack.replace(evaluation.scriptError.message, '').replace(/^Error:\s*\n/, '')));
      }

      console.log();
    } else if (evaluation.validationErrors.length === 0) {
      passed += 1;
      lastFailed = false;

      if (argv.showPasses) {
        console.log("".concat(_chalk["default"].inverse.bold.green(' PASS '), " ").concat(formattedPath));
      }
    } else {
      failed += 1;
      lastFailed = true;
      console.log("".concat(_chalk["default"].inverse.bold.red(' FAIL '), " ").concat(formattedPath));
      evaluation.validationErrors.forEach(function (error) {
        console.log("".concat(error.keyPath, " ").concat(_chalk["default"].red(error.message)));
      });
      console.log();
    }
  });

  if (passed + failed === 0) {
    console.log(_chalk["default"].bold.yellow('No tests run'));
    return;
  }

  if (!lastFailed) {
    console.log();
  }

  if (passed > 0) {
    console.log(_chalk["default"].bold.green("".concat(passed, " passed")));
  }

  if (failed > 0) {
    console.log(_chalk["default"].bold.red("".concat(failed, " failed")));
    process.exit(1);
  }
})["catch"](function (error) {
  console.log();
  console.log("".concat(_chalk["default"].inverse.bold.red(' ERROR '), " ").concat(error.message));
  console.log(_chalk["default"].dim(error.stack.replace(error.message, '').replace(/^Error:\s*\n/, '')));
  process.exit(1);
});