"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.evaluateFixtures = evaluateFixtures;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _path = require("path");

var _fsExtra = require("fs-extra");

var _graphql = require("graphql");

var _graphqlConfig = require("graphql-config");

var _graphqlConfigUtilities = require("graphql-config-utilities");

var _graphqlToolUtilities = require("graphql-tool-utilities");

var _validate = require("./validate.js");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function evaluateFixtures(_x, _x2) {
  return _evaluateFixtures.apply(this, arguments);
}

function _evaluateFixtures() {
  _evaluateFixtures = _asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee2(fixturePaths, _ref) {
    var cwd, config, projectASTCollection;
    return _regenerator["default"].wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            cwd = _ref.cwd;
            config = (0, _graphqlConfig.getGraphQLConfig)((0, _path.resolve)(cwd));
            _context2.next = 4;
            return Promise.all((0, _graphqlConfigUtilities.getGraphQLProjects)(config).map(getOperationsForProject));

          case 4:
            projectASTCollection = _context2.sent;
            return _context2.abrupt("return", runForEachFixture(fixturePaths, function (fixture) {
              return evaluateFixture(fixture, projectASTCollection);
            }));

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));
  return _evaluateFixtures.apply(this, arguments);
}

function getOperationsForProject(_x3) {
  return _getOperationsForProject.apply(this, arguments);
}

function _getOperationsForProject() {
  _getOperationsForProject = _asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee3(projectConfig) {
    var operationPaths, operationSources, document, schema;
    return _regenerator["default"].wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return (0, _graphqlConfigUtilities.getGraphQLProjectIncludedFilePaths)(projectConfig);

          case 2:
            operationPaths = _context3.sent;
            _context3.next = 5;
            return Promise.all(operationPaths.map(loadOperationSource));

          case 5:
            operationSources = _context3.sent;
            document = (0, _graphql.concatAST)(operationSources.map(function (source) {
              try {
                return (0, _graphql.parse)(source);
              } catch (error) {
                throw new Error("Error parsing '".concat(source.name, "':\n\n").concat(error.message.replace(/Syntax Error.*?\(.*?\) /, '')));
              }
            }));
            _context3.prev = 7;
            schema = projectConfig.getSchema();
            _context3.next = 14;
            break;

          case 11:
            _context3.prev = 11;
            _context3.t0 = _context3["catch"](7);
            throw new Error("Error parsing '".concat(projectConfig.schemaPath, "':\n\n").concat(_context3.t0.message.replace(/Syntax Error.*?\(.*?\) /, '')));

          case 14:
            return _context3.abrupt("return", {
              ast: (0, _graphqlToolUtilities.compile)(schema, document),
              config: projectConfig
            });

          case 15:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3, null, [[7, 11]]);
  }));
  return _getOperationsForProject.apply(this, arguments);
}

function loadOperationSource(_x4) {
  return _loadOperationSource.apply(this, arguments);
}

function _loadOperationSource() {
  _loadOperationSource = _asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee4(filePath) {
    var body;
    return _regenerator["default"].wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.next = 2;
            return (0, _fsExtra.readFile)(filePath, 'utf8');

          case 2:
            body = _context4.sent;
            return _context4.abrupt("return", new _graphql.Source(body, filePath));

          case 4:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  }));
  return _loadOperationSource.apply(this, arguments);
}

function runForEachFixture(fixturePaths, runner) {
  return Promise.all(fixturePaths.map( /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee(fixturePath) {
      var _fixture;

      return _regenerator["default"].wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.prev = 0;
              _context.next = 3;
              return (0, _fsExtra.readJSON)(fixturePath);

            case 3:
              _fixture = _context.sent;
              return _context.abrupt("return", _objectSpread({
                fixturePath: fixturePath
              }, runner({
                path: fixturePath,
                content: _fixture
              })));

            case 7:
              _context.prev = 7;
              _context.t0 = _context["catch"](0);
              return _context.abrupt("return", {
                fixturePath: fixturePath,
                scriptError: _context.t0,
                validationErrors: []
              });

            case 10:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[0, 7]]);
    }));

    return function (_x5) {
      return _ref2.apply(this, arguments);
    };
  }()));
}

function evaluateFixture(fixture, projectASTCollection) {
  try {
    var _getOperationForFixtu = (0, _validate.getOperationForFixture)(fixture, projectASTCollection),
        operation = _getOperationForFixtu.operation,
        ast = _getOperationForFixtu.projectAST.ast;

    return (0, _validate.validateFixture)(fixture, ast, operation);
  } catch (error) {
    if (error instanceof _validate.MissingOperationError || error instanceof _validate.AmbiguousOperationNameError) {
      return {
        fixturePath: fixture.path,
        validationErrors: [error]
      };
    }

    throw error;
  }
}