/* eslint no-console: off */
import { relative, basename } from 'path';
import yargs from 'yargs';
import * as glob from 'glob';
import chalk from 'chalk';
import { evaluateFixtures } from "./index.mjs";
var argv = yargs.usage('Usage: $0 <fixtures> [options]').option('cwd', {
  required: false,
  "default": process.cwd(),
  normalize: true,
  type: 'string',
  describe: 'Working directory where the .graphqlconfig is located'
}).option('show-passes', {
  type: 'boolean',
  "default": false,
  describe: 'Display passing fixtures along with failures in the console output'
}).help().argv;
evaluateFixtures(glob.sync(argv._[0]), {
  cwd: argv.cwd
}).then(function (evaluations) {
  var passed = 0;
  var failed = 0;
  var lastFailed = false;
  console.log();
  evaluations.forEach(function (evaluation) {
    var relativePath = relative(argv.cwd, evaluation.fixturePath);
    var formattedPath = "".concat(chalk.dim(relativePath.replace(basename(relativePath), ''))).concat(chalk.bold(basename(relativePath)));

    if (evaluation.scriptError) {
      failed += 1;
      lastFailed = true;
      console.log("".concat(chalk.inverse.bold.red(' FAIL '), " ").concat(formattedPath));
      console.log(evaluation.scriptError.message);

      if (evaluation.scriptError.stack) {
        console.log(chalk.dim(evaluation.scriptError.stack.replace(evaluation.scriptError.message, '').replace(/^Error:\s*\n/, '')));
      }

      console.log();
    } else if (evaluation.validationErrors.length === 0) {
      passed += 1;
      lastFailed = false;

      if (argv.showPasses) {
        console.log("".concat(chalk.inverse.bold.green(' PASS '), " ").concat(formattedPath));
      }
    } else {
      failed += 1;
      lastFailed = true;
      console.log("".concat(chalk.inverse.bold.red(' FAIL '), " ").concat(formattedPath));
      evaluation.validationErrors.forEach(function (error) {
        console.log("".concat(error.keyPath, " ").concat(chalk.red(error.message)));
      });
      console.log();
    }
  });

  if (passed + failed === 0) {
    console.log(chalk.bold.yellow('No tests run'));
    return;
  }

  if (!lastFailed) {
    console.log();
  }

  if (passed > 0) {
    console.log(chalk.bold.green("".concat(passed, " passed")));
  }

  if (failed > 0) {
    console.log(chalk.bold.red("".concat(failed, " failed")));
    process.exit(1);
  }
})["catch"](function (error) {
  console.log();
  console.log("".concat(chalk.inverse.bold.red(' ERROR '), " ").concat(error.message));
  console.log(chalk.dim(error.stack.replace(error.message, '').replace(/^Error:\s*\n/, '')));
  process.exit(1);
});