"use strict";

var _path = require("path");

var _yargs = _interopRequireDefault(require("yargs"));

var glob = _interopRequireWildcard(require("glob"));

var _chalk = _interopRequireDefault(require("chalk"));

var _index = require("./index.js");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-console: off */
const argv = _yargs.default.usage('Usage: $0 <fixtures> [options]').option('cwd', {
  required: false,
  default: process.cwd(),
  normalize: true,
  type: 'string',
  describe: 'Working directory where the .graphqlconfig is located'
}).option('show-passes', {
  type: 'boolean',
  default: false,
  describe: 'Display passing fixtures along with failures in the console output'
}).help().argv;

(0, _index.evaluateFixtures)(glob.sync(argv._[0]), {
  cwd: argv.cwd
}).then(evaluations => {
  let passed = 0;
  let failed = 0;
  let lastFailed = false;
  console.log();
  evaluations.forEach(evaluation => {
    const relativePath = (0, _path.relative)(argv.cwd, evaluation.fixturePath);
    const formattedPath = `${_chalk.default.dim(relativePath.replace((0, _path.basename)(relativePath), ''))}${_chalk.default.bold((0, _path.basename)(relativePath))}`;

    if (evaluation.scriptError) {
      failed += 1;
      lastFailed = true;
      console.log(`${_chalk.default.inverse.bold.red(' FAIL ')} ${formattedPath}`);
      console.log(evaluation.scriptError.message);

      if (evaluation.scriptError.stack) {
        console.log(_chalk.default.dim(evaluation.scriptError.stack.replace(evaluation.scriptError.message, '').replace(/^Error:\s*\n/, '')));
      }

      console.log();
    } else if (evaluation.validationErrors.length === 0) {
      passed += 1;
      lastFailed = false;

      if (argv.showPasses) {
        console.log(`${_chalk.default.inverse.bold.green(' PASS ')} ${formattedPath}`);
      }
    } else {
      failed += 1;
      lastFailed = true;
      console.log(`${_chalk.default.inverse.bold.red(' FAIL ')} ${formattedPath}`);
      evaluation.validationErrors.forEach(error => {
        console.log(`${error.keyPath} ${_chalk.default.red(error.message)}`);
      });
      console.log();
    }
  });

  if (passed + failed === 0) {
    console.log(_chalk.default.bold.yellow('No tests run'));
    return;
  }

  if (!lastFailed) {
    console.log();
  }

  if (passed > 0) {
    console.log(_chalk.default.bold.green(`${passed} passed`));
  }

  if (failed > 0) {
    console.log(_chalk.default.bold.red(`${failed} failed`));
    process.exit(1);
  }
}).catch(error => {
  console.log();
  console.log(`${_chalk.default.inverse.bold.red(' ERROR ')} ${error.message}`);
  console.log(_chalk.default.dim(error.stack.replace(error.message, '').replace(/^Error:\s*\n/, '')));
  process.exit(1);
});