"use strict";
/* eslint no-console: off */
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var path_1 = require("path");
var yargs_1 = tslib_1.__importDefault(require("yargs"));
var glob = tslib_1.__importStar(require("glob"));
var chalk_1 = tslib_1.__importDefault(require("chalk"));
var _1 = require(".");
var argv = yargs_1.default
    .usage('Usage: $0 <fixtures> [options]')
    .option('cwd', {
    required: false,
    default: process.cwd(),
    normalize: true,
    type: 'string',
    describe: 'Working directory where the .graphqlconfig is located',
})
    .option('show-passes', {
    type: 'boolean',
    default: false,
    describe: 'Display passing fixtures along with failures in the console output',
})
    .help().argv;
_1.evaluateFixtures(glob.sync(argv._[0]), {
    cwd: argv.cwd,
})
    .then(function (evaluations) {
    var passed = 0;
    var failed = 0;
    var lastFailed = false;
    console.log();
    evaluations.forEach(function (evaluation) {
        var relativePath = path_1.relative(argv.cwd, evaluation.fixturePath);
        var formattedPath = "" + chalk_1.default.dim(relativePath.replace(path_1.basename(relativePath), '')) + chalk_1.default.bold(path_1.basename(relativePath));
        if (evaluation.scriptError) {
            failed += 1;
            lastFailed = true;
            console.log(chalk_1.default.inverse.bold.red(' FAIL ') + " " + formattedPath);
            console.log(evaluation.scriptError.message);
            if (evaluation.scriptError.stack) {
                console.log(chalk_1.default.dim(evaluation.scriptError.stack
                    .replace(evaluation.scriptError.message, '')
                    .replace(/^Error:\s*\n/, '')));
            }
            console.log();
        }
        else if (evaluation.validationErrors.length === 0) {
            passed += 1;
            lastFailed = false;
            if (argv.showPasses) {
                console.log(chalk_1.default.inverse.bold.green(' PASS ') + " " + formattedPath);
            }
        }
        else {
            failed += 1;
            lastFailed = true;
            console.log(chalk_1.default.inverse.bold.red(' FAIL ') + " " + formattedPath);
            evaluation.validationErrors.forEach(function (error) {
                console.log(error.keyPath + " " + chalk_1.default.red(error.message));
            });
            console.log();
        }
    });
    if (passed + failed === 0) {
        console.log(chalk_1.default.bold.yellow('No tests run'));
        return;
    }
    if (!lastFailed) {
        console.log();
    }
    if (passed > 0) {
        console.log(chalk_1.default.bold.green(passed + " passed"));
    }
    if (failed > 0) {
        console.log(chalk_1.default.bold.red(failed + " failed"));
        process.exit(1);
    }
})
    .catch(function (error) {
    console.log();
    console.log(chalk_1.default.inverse.bold.red(' ERROR ') + " " + error.message);
    console.log(chalk_1.default.dim(error.stack.replace(error.message, '').replace(/^Error:\s*\n/, '')));
    process.exit(1);
});
