"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.evaluateFixtures = void 0;
var tslib_1 = require("tslib");
var path_1 = require("path");
var fs_extra_1 = require("fs-extra");
var graphql_1 = require("graphql");
var graphql_config_1 = require("graphql-config");
var graphql_config_utilities_1 = require("graphql-config-utilities");
var graphql_tool_utilities_1 = require("graphql-tool-utilities");
var validate_1 = require("./validate");
function evaluateFixtures(fixturePaths, _a) {
    var cwd = _a.cwd;
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var config, projectASTCollection;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    config = graphql_config_1.getGraphQLConfig(path_1.resolve(cwd));
                    return [4 /*yield*/, Promise.all(graphql_config_utilities_1.getGraphQLProjects(config).map(getOperationsForProject))];
                case 1:
                    projectASTCollection = _b.sent();
                    return [2 /*return*/, runForEachFixture(fixturePaths, function (fixture) {
                            return evaluateFixture(fixture, projectASTCollection);
                        })];
            }
        });
    });
}
exports.evaluateFixtures = evaluateFixtures;
function getOperationsForProject(projectConfig) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var operationPaths, operationSources, document, schema;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, graphql_config_utilities_1.getGraphQLProjectIncludedFilePaths(projectConfig)];
                case 1:
                    operationPaths = _a.sent();
                    return [4 /*yield*/, Promise.all(operationPaths.map(loadOperationSource))];
                case 2:
                    operationSources = _a.sent();
                    document = graphql_1.concatAST(operationSources.map(function (source) {
                        try {
                            return graphql_1.parse(source);
                        }
                        catch (error) {
                            throw new Error("Error parsing '" + source.name + "':\n\n" + error.message.replace(/Syntax Error.*?\(.*?\) /, ''));
                        }
                    }));
                    try {
                        schema = projectConfig.getSchema();
                    }
                    catch (error) {
                        throw new Error("Error parsing '" + projectConfig.schemaPath + "':\n\n" + error.message.replace(/Syntax Error.*?\(.*?\) /, ''));
                    }
                    return [2 /*return*/, {
                            ast: graphql_tool_utilities_1.compile(schema, document),
                            config: projectConfig,
                        }];
            }
        });
    });
}
function loadOperationSource(filePath) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var body;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, fs_extra_1.readFile(filePath, 'utf8')];
                case 1:
                    body = _a.sent();
                    return [2 /*return*/, new graphql_1.Source(body, filePath)];
            }
        });
    });
}
function runForEachFixture(fixturePaths, runner) {
    var _this = this;
    return Promise.all(fixturePaths.map(function (fixturePath) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var fixture, error_1;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    _a.trys.push([0, 2, , 3]);
                    return [4 /*yield*/, fs_extra_1.readJSON(fixturePath)];
                case 1:
                    fixture = _a.sent();
                    return [2 /*return*/, tslib_1.__assign({ fixturePath: fixturePath }, runner({ path: fixturePath, content: fixture }))];
                case 2:
                    error_1 = _a.sent();
                    return [2 /*return*/, {
                            fixturePath: fixturePath,
                            scriptError: error_1,
                            validationErrors: [],
                        }];
                case 3: return [2 /*return*/];
            }
        });
    }); }));
}
function evaluateFixture(fixture, projectASTCollection) {
    try {
        var _a = validate_1.getOperationForFixture(fixture, projectASTCollection), operation = _a.operation, ast = _a.projectAST.ast;
        return validate_1.validateFixture(fixture, ast, operation);
    }
    catch (error) {
        if (error instanceof validate_1.MissingOperationError ||
            error instanceof validate_1.AmbiguousOperationNameError) {
            return {
                fixturePath: fixture.path,
                validationErrors: [error],
            };
        }
        throw error;
    }
}
